pub trait Verifier {
// Required method
fn verify(
&self,
script_pubkeys: &HashMap<usize, ScriptBuf>,
tx_to: &Transaction,
spent_outputs: &[TxOut],
) -> Result<(), Error>;
}Expand description
Trait to abstract the behavior of the bitcoin script verifier, allowing users to provide their own verifier.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".